@@ -191,11 +191,13 @@ void Document::SetFileName (string const &Name, const gchar* mime_type)
 	list<string>::iterator cur, end = exts.end ();
 	for (cur = exts.begin (); cur != end; cur++)
 		if (*cur == ext) {
-			m_label = g_strndup (m_filename + i, j - i);
+			char *buf = g_strndup (m_filename + i, j - i);
+			m_label = g_uri_unescape_string (buf, NULL);
+			g_free (buf);
 			break;
 		}
 	if (!m_label)
-		m_label = g_strdup (m_filename + i);
+		m_label = g_uri_unescape_string (m_filename + i, NULL);
 }
 
 void Document::BuildBondList (list<Bond*>& BondList, Object const *obj) const
@@ -426,7 +428,7 @@ void Document::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) cons
 	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (widget), "data");
 	ArtDRect rect;
 	pData->GetObjectBounds (this, &rect);
-	double scale = 1.;
+	double scale = .75;
 	x = rect.x0;
 	y = rect.y0;
 	w = rect.x1 - rect.x0;
@@ -439,10 +441,6 @@ void Document::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) cons
 		break;
 	case GCU_PRINT_SCALE_FIXED:
 		scale *= Printable::GetScale ();
-		x *= scale;
-		y *= scale;
-		w *= scale;
-		h *= scale;
 		break;
 	case GCU_PRINT_SCALE_AUTO:
 		if (GetHorizFit () && GetVertFit ())
@@ -451,12 +449,12 @@ void Document::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) cons
 			scale *= width / w;
 		else if (GetVertFit ())
 			scale *= height / h;
-		x *= scale;
-		y *= scale;
-		w *= scale;
-		h *= scale;
 		break;
 	}
+	x *= scale;
+	y *= scale;
+	w *= scale;
+	h *= scale;
 	if (GetHorizCentered ())
 		x -= (width - w) / 2;
 	if (GetVertCentered ())
@@ -621,6 +619,16 @@ void Document::Save () const
 			xmlOutputBufferPtr buf = xmlAllocOutputBuffer (NULL);
 			GFile *file = g_file_new_for_uri (m_filename);
 			GError *error = NULL;
+			if (g_file_query_exists (file, NULL)) {
+				// FIXME: for now, delete it, but we might make a backup?
+				g_file_delete (file, NULL, &error);
+				if (error) {
+					g_message ("GIO error: %s", error->message);
+					g_error_free (error);
+					g_object_unref (file);
+					throw (int) 1;
+				}
+			}
 			GOutputStream *output = G_OUTPUT_STREAM (g_file_create (file, G_FILE_CREATE_NONE, NULL, &error));
 			if (error) {
 				g_message ("GIO error: %s", error->message);
@@ -1286,12 +1294,12 @@ double Document::GetYAlign ()
 
 void Document::SetTheme (Theme *theme)
 {
+	if (m_Theme)
+		m_Theme->RemoveClient (this);
 	if (!theme) {
 		m_Theme = NULL;
 		return;
 	}
-	if (m_Theme)
-		m_Theme->RemoveClient (this);
 	m_Theme = theme;
 	m_Theme->AddClient (this);
 	m_BondLength = theme->GetBondLength ();
