@@ -63,46 +63,60 @@ static ResiduesTable tbl;
 Residue::Residue ():
 	m_Name (NULL),
 	m_Generic (false),
-	m_Molecule (NULL)
+	m_Document (NULL),
+	m_Molecule (NULL),
+	m_Owner (NULL)
 {
 }
 
-Residue::Residue (char const *name):
+Residue::Residue (char const *name, Document *doc):
 	m_Generic (false),
-	m_Molecule (NULL)
+	m_Document (NULL),
+	m_Molecule (NULL),
+	m_Owner (doc)
 {
-	m_Name = g_strdup (name);
-	tbl.rtbn[name] = this;
+	if (name) {
+		m_Name = g_strdup (name);
+		if (!m_Owner)
+			tbl.rtbn[name] = this;
+	} else
+		m_Name = NULL;
 }
 
 Residue::~Residue ()
 {
-	if (m_Name)
-		tbl.rtbn.erase (m_Name);
-	std::map<std::string, bool>::iterator i, end = m_Symbols.end ();
-	for (i = m_Symbols.begin (); i != end ; i++)
-		tbl.rtbs.erase ((*i).first);
+	if (!m_Owner) {
+		if (m_Name)
+			tbl.rtbn.erase (m_Name);
+		std::map<std::string, bool>::iterator i, end = m_Symbols.end ();
+		for (i = m_Symbols.begin (); i != end ; i++)
+			tbl.rtbs.erase ((*i).first);
+	}
 	g_free (const_cast<char*> (m_Name));
+	if (m_Document)
+		delete m_Document;
 }
 
 unsigned Residue::MaxSymbolLength = 0;
 
 void Residue::SetName (char const *name)
 {
-	if (m_Name) {
+	if (!m_Owner && m_Name)
 		tbl.rtbn.erase (m_Name);
-		g_free (const_cast<char*> (m_Name));
-	}
+	g_free (const_cast<char*> (m_Name));
 	m_Name = g_strdup (name);
-	tbl.rtbn[name] = this;
+	if (!m_Owner)
+		tbl.rtbn[name] = this;
 }
 
 void Residue::AddSymbol (char const *symbol)
 {
 	bool ambiguous = Element::Z (symbol) > 0;
 	m_Symbols[symbol] = ambiguous;
-	tbl.rtbs[symbol].res = this;
-	tbl.rtbs[symbol].ambiguous = ambiguous;
+	if (!m_Owner) {
+		tbl.rtbs[symbol].res = this;
+		tbl.rtbs[symbol].ambiguous = ambiguous;
+	}
 	unsigned l = strlen (symbol);
 	if (l > MaxSymbolLength)
 		MaxSymbolLength = l;
@@ -111,7 +125,8 @@ void Residue::AddSymbol (char const *symbol)
 void Residue::RemoveSymbol (char const *symbol)
 {
 	m_Symbols.erase (symbol);
-	tbl.rtbs.erase (symbol);
+	if (!m_Owner)
+		tbl.rtbs.erase (symbol);
 }
 
 void Residue::Load (xmlNodePtr node)
@@ -155,13 +170,14 @@ void Residue::Load (xmlNodePtr node)
 						lang_matched = true;
 					}
 				}
-				xmlFree (node_lang);
 			} else if (!lang_matched) {
 				if (name)
 					xmlFree (name);
 				name = reinterpret_cast <char *> (xmlNodeGetContent (child));
 			}
 			m_Names[(node_lang)? node_lang: "C"] = reinterpret_cast <char const *> (xmlNodeGetContent (child));
+			if (node_lang)
+				xmlFree (node_lang);
 		} else if (!strcmp (reinterpret_cast <char const *> (child->name), "symbols")) {
 			symbols = reinterpret_cast <char *> (xmlNodeGetContent (child));
 			std::istringstream s(symbols);
@@ -173,7 +189,7 @@ void Residue::Load (xmlNodePtr node)
 						cerr << "Symbol \"" << buf << "\" has more than eight characters and is not allowed" << endl;
 					delete this;
 					return;
-				} else {
+				} else if (!m_Owner) {
 					if (GetResidue (buf) != NULL) {
 						cerr << "A residue with symbol \"" << buf << "\" already exists" << endl;
 						delete this;
@@ -193,16 +209,18 @@ void Residue::Load (xmlNodePtr node)
 		}
 		child = child->next;
 	}
-	if (name) {
-		if (GetResiduebyName (name) != NULL) {
-			cerr << "A residue named \"" << name << "\" already exists" << endl;
+	if (!m_Owner) {
+		if (name) {
+			if (GetResiduebyName (name) != NULL) {
+				cerr << "A residue named \"" << name << "\" already exists" << endl;
+				delete this;
+				return;
+			}
+			SetName (name);
+			xmlFree (name);
+		} else
 			delete this;
-			return;
-		}
-		SetName (name);
-		xmlFree (name);
-	} else
-		delete this;
+	}
 }
 
 Residue const *Residue::GetResidue (char const *symbol, bool *ambiguous)
