@@ -4,7 +4,9 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
-#include <libgnomevfs/gnome-vfs.h>
+#ifdef GOFFICE_IS_0_6
+#	include <libgnomevfs/gnome-vfs.h>
+#endif
 
 /*!\file
 A simple sample of the use of the GtkChem3DViewer widget.
@@ -25,10 +27,12 @@ int main (int argc, char *argv[])
 	GtkWidget *viewer;
 	gchar* uri;
 	gtk_init (&argc, &argv);
+#ifdef GOFFICE_IS_0_6
 	if (!gnome_vfs_init ()) {
 		printf ("Could not initialize GnomeVFS\n");
 		return 1;
 	}
+#endif
 	
 	gcu_element_load_databases ("radii", NULL);
 
